Stan Math Library: Class Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

- All
- Functions
- Variables
- Typedefs
- Enumerator
- Related Functions

- _
- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- v
- w
- x
- y
- ~

Here is a list of all class members with links to the classes they belong to:

### - n -

- n_ : stan::math::coupled_ode_observer
- N_ : stan::math::coupled_ode_system< F, double, double > , stan::math::coupled_ode_system< F, double, stan::math::var > , stan::math::coupled_ode_system< F, stan::math::var, double > , stan::math::coupled_ode_system< F, stan::math::var, stan::math::var > , stan::math::LDLT_alloc< R, C > , stan::math::LDLT_factor< T, R, C >
- n_partials : stan::math::OperandsAndPartials< T1, T2, T3, T4, T5, T6, typename stan::math::fvar< T_partials_return > >
- Nested : Eigen::NumTraits< stan::math::fvar< T > > , Eigen::NumTraits< stan::math::var >
- nested_var_alloc_stack_starts_ : stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >
- nested_var_nochain_stack_sizes_ : stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >
- nested_var_stack_sizes_ : stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >
- NonInteger : Eigen::NumTraits< stan::math::fvar< T > > , Eigen::NumTraits< stan::math::var >
- num_samples() : stan::math::welford_covar_estimator , stan::math::welford_var_estimator
- nvaris : stan::math::OperandsAndPartials< T1, T2, T3, T4, T5, T6, stan::math::var >

[ Stan Home Page ] © 2011–2016, Stan Development Team.